@@ -60,7 +60,9 @@ class TemplateExtractor:
         if sentence[0].isupper():
             sentence = sentence[0].lower() + sentence[1:]
         # sentence = self.eliminate_bracket(sentence)
+        sentence = re.sub(r'\{@.*?\s+(.+?)\}', r'\1', sentence)
         sentence = re.compile(r'<[^>]*>|\([^\)]*\)|\[[^\]]*\]|\{[^\}]*\}', re.S).sub('', sentence)
+        sentence = re.sub(r'\s+', ' ', sentence)
         return sentence
 
     @staticmethod
